%define _localstatedir /var

%define pversion 9.7.1P2
%define sversion 9.7.1-P2

%define bind_uid  25
%define bind_gid  25

Summary: A DNS (Domain Name System) server.
Summary(ja): DNS (Domain Name System) サーバ
Name: bind
Version: %{pversion}
Release: 1%{?_dist_release}
License: distributable
Group: System Environment/Daemons
Source: ftp://ftp.isc.org/isc/bind9/%{version}/%{name}-%{sversion}.tar.gz
Source1: bind-manpages.tar.bz2
Source2: named.sysconfig
Source3: named.init
Source4: named.logrotate
Source5: keygen.c
URL: http://www.isc.org/bind.html
Patch1: bind-9.3.3rc2-rndckey.patch

Buildroot: %{_tmppath}/%{name}-%{version}-root
BuildRequires: openssl-devel glibc-devel libtool
Requires: bind-libs = %{version}-%{release}
Requires(pre): shadow-utils
Requires(post): bind-utils = %{version}-%{release}
Requires(post): coreutils, chkconfig
Requires(preun): initscripts, chkconfig
Requires(triggerpostun): chkconfig
Conflicts: bind9 <= 9.2.1-0vl5
Obsoletes: bind9 <= 9.2.1-0vl5

Vendor: Project Vine
Distribution: Vine Linux
Packager: daisuke

%description
BIND (Berkeley Internet Name Domain) is an implementation of the DNS
(Domain Name System) protocols. BIND includes a DNS server (named), 
which resolves host names to IP addresses, and a resolver library 
(routines for applications to use when interfacing with DNS).  A DNS 
server allows clients to name resources or objects and share the 
information with other network machines.  The named DNS server can be 
used on workstations as a caching name server, but is generally only 
needed on one machine for an entire network.  Note that the 
configuration files for making BIND act as a simple caching nameserver 
are included in the caching-nameserver package.  

Install the bind package if you need a DNS server for your network.  If
you want bind to act a caching name server, you will also need to install
the caching-nameserver package.


%package libs
Summary: Libraries used by various DNS packages
Group: System Environment/Libraries

%description libs
Contains libraries used by both the bind server package as well as the utils packages.


%package utils
Summary: Utilities for querying DNS name servers.
Summary(ja): DNS ネームサーバに問い合わせをするユーティリティ
Group: Applications/System
Requires: bind-libs = %{version}-%{release}
Conflicts: bind9-utils <= 9.2.1-0vl5
Obsoletes: bind9-utils <= 9.2.1-0vl5


%description utils
Bind-utils contains a collection of utilities for querying DNS (Domain
Name Service) name servers to find out information about Internet hosts.
These tools will provide you with the IP addresses for given host names,
as well as other information about registered domains and network 
addresses.

You should install bind-utils if you need to get information from DNS name
servers.


%package devel
Summary: Include files and libraries needed for bind DNS development.
Summary(ja): bind DNS 開発に必要なインクルードファイルとライブラリ
Group: Development/Libraries
Requires: bind >= 9.2.1-0vl7
Requires: bind-libs = %{version}-%{release}
Conflicts: bind9-devel <= 9.2.1-0vl5
Obsoletes: bind9-devel <= 9.2.1-0vl5


%description devel
The bind-devel package contains all the include files and the 
library required for DNS (Domain Name Service) development for 
BIND versions 9.x.x.

You should install bind-devel if you want to develop bind DNS
applications. If you install bind-devel, you'll also need to install
bind.
#'

%prep
%setup -n bind-%{sversion} -q
%patch1 -p1 -b .key

%build
libtoolize --copy --force
aclocal
autoconf
%configure --with-libtool --with-openssl=/usr --enable-threads
make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p ${RPM_BUILD_ROOT}%{_sysconfdir}/{rc.d/init.d,logrotate.d}
mkdir -p ${RPM_BUILD_ROOT}/usr/{bin,lib,sbin,include}
mkdir -p ${RPM_BUILD_ROOT}/var/named
mkdir -p ${RPM_BUILD_ROOT}%{_mandir}/{man1,man5,man8}
mkdir -p ${RPM_BUILD_ROOT}/var/run/named

make DESTDIR=$RPM_BUILD_ROOT install
install -c -m 640 bin/rndc/rndc.conf $RPM_BUILD_ROOT/etc
install -c -m 755 contrib/named-bootconf/named-bootconf.sh $RPM_BUILD_ROOT/usr/sbin/named-bootconf
install -c -m 755 %SOURCE3 $RPM_BUILD_ROOT%{_sysconfdir}/rc.d/init.d/named
install -c -m 644 %SOURCE4 $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/named
touch $RPM_BUILD_ROOT%{_sysconfdir}/rndc.key
gcc $RPM_OPT_FLAGS -o $RPM_BUILD_ROOT/usr/sbin/dns-keygen %{SOURCE5}
cd $RPM_BUILD_ROOT%{_mandir}
tar xjf %{SOURCE1}
# newer version is contained in source
rm -f man5/named.conf.5.gz
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig
cp %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/named


%pre
if [ "$1" -eq 1 ]; then
  /usr/sbin/groupadd -g %{bind_gid} -f -r named >/dev/null 2>&1 || :;
  /usr/sbin/useradd  -u %{bind_uid} -r -N -M -g named -s /sbin/nologin -d /var/named -c Named named >/dev/null 2>&1 || :;
fi;
:;

%post
/sbin/ldconfig
/sbin/chkconfig --add named
if [ "$1" -eq 1 ]; then
  if [ ! -e /etc/rndc.key ]; then
    /usr/sbin/rndc-confgen -a > /dev/null 2>&1
  fi
  [ -x /sbin/restorecon ] && /sbin/restorecon /etc/rndc.* /etc/named.* >/dev/null 2>&1 ;
  # rndc.key has to have correct perms and ownership, CVE-2007-6283
  [ -e /etc/rndc.key ] && chown root:named /etc/rndc.key
  [ -e /etc/rndc.key ] && chmod 0640 /etc/rndc.key

  # Check DNSSEC settings if this is a fresh install
  if [ -r /etc/sysconfig/dnssec ]; then
    . /etc/sysconfig/dnssec
    [ -x /usr/sbin/dnssec-configure ] && \
      dnssec-configure -b --norestart --dnssec="$DNSSEC" --dlv="$DLV" > \
        /dev/null 2>&1
  fi;
fi
:;

%preun
if [ "$1" -eq 0 ]; then
   /sbin/service named stop >/dev/null 2>&1 || :
   /sbin/chkconfig --del named ||:
fi
exit 0


%postun
if [ "$1" -ge 1 ]; then
        %{_sysconfdir}/rc.d/init.d/named condrestart >/dev/null 2>&1 || :
fi
/sbin/ldconfig

%triggerpostun -- bind < 8.2.2_P5-15
/sbin/chkconfig --add named
/sbin/ldconfig

%clean
rm -rf ${RPM_BUILD_ROOT} ${RPM_BUILD_DIR}/%{name}-%{version}


%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig


%files
%defattr(-,root,root)
%doc CHANGES README
%doc doc/arm doc/draft doc/rfc doc/misc
%config(noreplace) %{_sysconfdir}/logrotate.d/named
%config %{_sysconfdir}/rc.d/init.d/named
%config(noreplace) %{_sysconfdir}/sysconfig/named
%config(noreplace) %attr(0640,root,named) %{_sysconfdir}/rndc.conf
%config(noreplace) %attr(0640,root,named) %{_sysconfdir}/rndc.key

%{_sbindir}/dnssec*
%{_sbindir}/lwresd
%{_sbindir}/named
%{_sbindir}/named-bootconf
%{_sbindir}/named-check*
%{_sbindir}/named-compilezone
%{_sbindir}/rndc*
%{_sbindir}/dns-keygen

#%{_libdir}/libbind9.so.*
#%{_libdir}/libisccc.so.*
#%{_libdir}/libisccfg.so.*

%{_mandir}/man5/resolv.conf.5*
%{_mandir}/man5/named.conf.5*
%{_mandir}/man5/rndc.conf.5*
%{_mandir}/man8/rndc.8*
%{_mandir}/man8/named.8*
%{_mandir}/man8/lwresd.8*
%{_mandir}/man8/dnssec*.8*
%{_mandir}/man8/named-checkconf.8*
%{_mandir}/man8/named-checkzone.8*
%{_mandir}/man8/named-compilezone.8*
%{_mandir}/man8/rndc-confgen.8*

%attr(-,named,named) %dir %{_var}/named
%attr(-,named,named) %dir %{_var}/run/named
     

%files libs
%defattr(-,root,root)
%{_libdir}/*.so.*

%files utils
%defattr(-,root,root)
%{_bindir}/dig
%{_bindir}/host
%{_bindir}/nslookup
%{_bindir}/nsupdate
#%{_libdir}/libdns.so.*
#%{_libdir}/libisc.so.*
#%{_libdir}/liblwres.so.*
%{_mandir}/man1/host.1*
%{_mandir}/man1/nsupdate.1*
%{_mandir}/man1/dig.1*
%{_mandir}/man5/resolver.5*
%{_mandir}/man1/nslookup.1*
%{_mandir}/man8/nslookup.8*


%files devel
%defattr(-,root,root)
%{_libdir}/*.so
%{_libdir}/*.la
%{_libdir}/*.a
%{_includedir}/*
%{_mandir}/man3/*
%{_mandir}/man1/isc-config.sh.1*
%{_bindir}/isc-config.sh

%changelog
* Sat Jul 17 2010 Daisuke SUZUKI <daisuke@linux.or.jp> 9.7.1P2-1
- new upstream release

* Fri Feb 12 2010 MATSUBAYASHI Kohji <shaolin@vinelinux.org> - 9.6.1P3-4
- rebuilt with gcc-4.4.3-3 on ppc

* Sat Feb  6 2010 Ryoichi INAGAKI <ryo1@bc.wakwak.com> 9.6.1P3-3
- rebuilt with new toolchains (for VineSeed)
- s/BuildPrereq/BuildRequires/

* Thu Jan 21 2010 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 9.6.1P3-2
- add man1/isc-config.sh.1 into devel file list

* Wed Jan 20 2010 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 9.6.1P3-1
- new upstream release with security fix (CVE-2009-4022, 2010-0097)  

* Sat Dec 12 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 9.6.1P2-1
- new upstream release with security fix (CVE-2009-4022) 

* Wed Jul 29 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 9.6.1P1-1
- new upstream release with security fix 

* Wed Jul 01 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 9.6.1-1
- new upstream release
- clean up %%post/%%pre scriptlet
  - create named user and group in %%pre
  - don't remove named user/group in %%preun
  - use rndc-confgen to create rndc.key

* Thu Apr 30 2009 Daisuke SUZUKI <daisuke@linux.or.jp> 9.6.0P1-1
- new upstream release
- drop patch0 and patch14, merged in upstream

* Sat Jan 11 2009 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 9.5.1P1-1
- new upstream release with security fix

* Wed Jul 09 2008 Daisuke SUZUKI <daisuke@linux.or.jp> 9.5.0P1-1
- new upstream release with security fix
- new versioning policy

* Sun Sep 30 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 9.4.1P1-0vl1
- new upstream release with security fix

* Fri May 18 2007 Daisuke SUZUKI <daisuke@linux.or.jp> 9.4.1-0vl1
- new upstream release
- build with new openssl/toolchain

* Tue Jan 30 2007 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 9.3.4-0vl1
- new upstream release with security fix

* Fri Nov 03 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 9.3.2P2-0vl1
- new upstream release

* Fri Sep 08 2006 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 9.3.2P1-0vl2
- add Prereq sed

* Wed Sep 06 2006 Satoshi IWAMOTO <satoshi.iwamoto@nifty.ne.jp> 9.3.2P1-0vl1
- new upstream release for security fix (CVE-2006-4095,4096)

* Wed Feb 15 2006 KAZUKI SHIMURA <kazuki@ma.ccnw.ne.jp> 9.3.2-0vl3
- separate -libs package
- remove old named.conf.5.gz
  - newer version is contained in source

* Thu Feb 09 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 9.3.2-0vl2
- add bsdcompat patch (Patch4)
- add fix_h_errno patch from FC
  - h_errno not being accessed / set correctly in libbind

* Thu Feb 09 2006 Daisuke SUZUKI <daisuke@linux.or.jp> 9.3.2-0vl1
- new upstream release

* Sun Nov  7 2004 MATSUBAYASHI Kohji <shaolin@vinelinux.org> 9.2.4-0vl2
- added PreReq to bind-utils (see: [VineSeed:09555])

* Thu Oct 28 2004 Daisuke SUZUKI <daisuke@linux.or.jp> 9.2.4-0vl1
- new upstream release

* Wed Nov 19 2003 Daisuke SUZUKI <daisuke@linux.or.jp> 9.2.3-0vl3
- fix /etc/init.d/named to use rndc

* Tue Nov 18 2003 Daisuke SUZUKI <daisuke@linux.or.jp> 9.2.3-0vl2
- rebuild to remove unneeded dependancy

* Mon Nov 17 2003 Daisuke SUZUKI <daisuke@linux.or.jp> 9.2.3-0vl1
- new upstream release

* Tue Mar  4 2003 Daisuke SUZUKI <daisuke@linux.or.jp> 9.2.2-0vl1
- new upstream release

* Thu Nov 28 2002 Daisuke SUZUKI <daisuke@linux.or.jp> 9.2.1-0vl7
- fix dependancies.

* Wed Nov 27 2002 Daisuke SUZUKI <daisuke@linux.or.jp> 9.2.1-0vl6
- add obsoletes: and conflicts: to bind9, bind9-utils, bind9-devel <= 9.2.1-0vl5
- change package name to bind for VineSeed.
- use more macros.

* Sat Oct 19 2002 Daisuke SUZUKI <daisuke@linux.or.jp> 9.2.1-0vl5
- fixed some macros
- add conflicts: to bind-* in bind9-devel and bind9-utils
- add provides: bind = %%{version}

* Sat Oct 19 2002 Daisuke SUZUKI <daisuke@linux.or.jp> 9.2.1-0vl4
- use %%configure macros

* Sat Oct 19 2002 Michihide Hotta <hotta@net-newbie.com> 9.2.1-0vl3
- fixed inconsistent dependency

* Wed Aug 14 2002 Satoshi MACHINO <machino@vinelinux.org> 9.2.1-0vl2
- updated to 9.2.2rc1

* Thu May 02 2002 Satoshi MACHINO <machino@vinelinux.org> 9.2.1-0vl0
- updated to bind9(9.2.1), test packages ;)
	-- based on Rawhide's bind-9.2.0-8
	-- changed name bind9
	-- added Conflicts: bind

* Sun Feb 03 2002 Toru Sagami <sagami@vinelinux.org> 8.3.1-0vl1
- release 8.3.1 includes security fixes

* Mon Jan 14 2002 Toru Sagami <sagami@vinelinux.org> 8.3.0-0vl1
- Upgraded to current stable release 8.3.0

* Mon Oct  8 2001 <zn@mbf.nifty.com>
- 8.2.5-0vl0: Upgraded to new upstream version.

* Thu May 24 2001 <sagami@vinelinux.org>
- 8.2.4-0vl1: eliminate CVS related files from %%doc

* Thu May 17 2001 <sagami@vinelinux.org>
- 8.2.4-0vl0

* Fri Feb 02 2001 MATSUBAYASHI 'Shaolin' Kohji <shaolin@rhythmaning.org>
- 8.2.3-1vl2
- built on VineSeed

* Tue Jan 30 2001 KAJIKI Yoshihiro <kajiki@ylug.org>
- add doc/old
- build for Vine 2.1

* Sat Jan 27 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- 8.2.3, fixes several security problems

* Tue Nov 14 2000 Bill Nottingham <notting@redhat.com>
- static libraries may be used in shared objects. Build with -fPIC on ia64

* Fri Nov 10 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- 8.2.2-P7 (fixes Bug #20546)

* Sat Aug 05 2000 Bill Nottingham <notting@redhat.com>
- condrestart fixes

* Tue Jul 18 2000 Nalin Dahyabhai <nalin@redhat.com>
- change the init script to take condrestart, not cond-restart
- add sh-utils, /bin/cat, perl, /bin/chmod, /usr/sbin/useradd as prereqs for
  the %pre and %post scripts

* Sun Jul 16 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Don't prereq /etc/init.d

* Sat Jul 15 2000 Bill Nottingham <notting@redhat.com>
- move initscript back

* Wed Jul 12 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Sun Jul  9 2000 Florian La Roche <Florian.LaRoche@redhat.de>
- add "exit 0" for uninstall case

* Fri Jul  7 2000 Florian La Roche <Florian.LaRoche@redhat.de>
- add prereq init.d and cleanup install section

* Fri Jun 30 2000 Trond Eivind Glomsr <teg@redhat.com>
- fix the init script

* Wed Jun 28 2000 Nalin Dahyabhai <nalin@redhat.com>
- make libbind.a and nslookup.help readable again by setting INSTALL_LIB to ""

* Mon Jun 26 2000 Bernhard Rosenkr舅zer <bero@redhat.com>
- Fix up the initscript (Bug #13033)
- Fix build with current glibc (Bug #12755)
- /etc/rc.d/init.d -> /etc/init.d
- use %%{_mandir} rather than /usr/share/man

* Mon Jun 19 2000 Bill Nottingham <notting@redhat.com>
- fix conflict with man-pages
- remove compatibilty chkconfig links
- initscript munging

* Wed Jun 14 2000 Nalin Dahyabhai <nalin@redhat.com>
- modify logrotate setup to use PID file
- temporarily disable optimization by unsetting $RPM_OPT_FLAGS at build-time
- actually bump the release this time

* Sun Jun  4 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- FHS compliance

* Mon Apr 17 2000 Nalin Dahyabhai <nalin@redhat.com>
- clean up restart patch

* Mon Apr 10 2000 Nalin Dahyabhai <nalin@redhat.com>
- provide /var/named (fix for bugs #9847, #10205)
- preserve args when restarted via ndc(8) (bug #10227)
- make resolv.conf(5) a link to resolver(5) (bug #10245)
- fix SYSTYPE bug in all makefiles
- move creation of named user from %%post into %%pre

* Mon Feb 28 2000 Bernhard Rosenkr舅zer <bero@redhat.com>
- Fix TTL (patch from ISC, Bug #9820)

* Wed Feb 16 2000 Bernhard Rosenkr舅zer <bero@redhat.com>
- fix typo in spec (it's %post, without a leading blank) introduced in -6
- change SYSTYPE to linux

* Sat Feb 11 2000 Bill Nottingham <notting@redhat.com>
- pick a standard < 100 uid/gid for named

* Thu Feb 04 2000 Elliot Lee <sopwith@redhat.com>
- Pass named a '-u named' parameter by default, and add/remove user.

* Thu Feb  3 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- fix host mx bug (Bug #9021)

* Mon Jan 31 2000 Cristian Gafton <gafton@redhat.com>
- rebuild to fix dependencies
- man pages are compressed

* Wed Jan 19 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- It's /usr/bin/killall, not /usr/sbin/killall (Bug #8063)

* Mon Jan 17 2000 Bernhard Rosenkraenzer <bero@redhat.com>
- Fix up location of named-bootconf.pl and make it executable
  (Bug #8028)
- bind-devel requires bind

* Mon Nov 15 1999 Bernhard Rosenkraenzer <bero@redhat.com>
- update to 8.2.2-P5

* Wed Nov 10 1999 Bill Nottingham <notting@redhat.com>
- update to 8.2.2-P3

* Tue Oct 12 1999 Cristian Gafton <gafton@redhat.com>
- add patch to stop a cache only server from complaining about lame servers
  on every request.

* Fri Sep 24 1999 Preston Brown <pbrown@redhat.com>
- use real stop and start in named.init for restart, not ndc restart, it has
  problems when named has changed during a package update... (# 4890)

* Fri Sep 10 1999 Bill Nottingham <notting@redhat.com>
- chkconfig --del in %preun, not %postun

* Mon Aug 16 1999 Bill Nottingham <notting@redhat.com>
- initscript munging

* Mon Jul 26 1999 Bill Nottingham <notting@redhat.com>
- fix installed chkconfig links to match init file

* Sat Jul  3 1999 Jeff Johnson <jbj@redhat.com>
- conflict with new (in man-1.24) man pages (#3876,#3877).

* Tue Jun 29 1999 Bill Nottingham <notting@redhat.com>
- fix named.logrotate (wrong %SOURCE)

* Fri Jun 25 1999 Jeff Johnson <jbj@redhat.com>
- update to 8.2.1.
- add named.logrotate (#3571).
- hack around egcs-1.1.2 -m486 bug (#3413, #3485).
- vet file list.

* Fri Jun 18 1999 Bill Nottingham <notting@redhat.com>
- don't run by default

* Sun May 30 1999 Jeff Johnson <jbj@redhat.com>
- nslookup fixes (#2463).
- missing files (#3152).

* Sat May  1 1999 Stepan Kasal <kasal@math.cas.cz>
- nslookup patched:
  to count numRecords properly
  to fix subsequent calls to ls -d
  to parse "view" and "finger" commands properly
  the view hack updated for bind-8 (using sed)

* Wed Mar 31 1999 Bill Nottingham <notting@redhat.com>
- add ISC patch
- add quick hack to make host not crash
- add more docs

* Fri Mar 26 1999 Cristian Gafton <gafton@redhat.com>
- add probing information in the init file to keep linuxconf happy
- dont strip libbind

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 3)

* Wed Mar 17 1999 Preston Brown <pbrown@redhat.com>
- removed 'done' output at named shutdown.

* Tue Mar 16 1999 Cristian Gafton <gafton@redhat.com>
- version 8.2

* Wed Dec 30 1998 Cristian Gafton <gafton@redhat.com>
- patch to use the __FDS_BITS macro
- build for glibc 2.1

* Wed Sep 23 1998 Jeff Johnson <jbj@redhat.com>
- change named.restart to /usr/sbin/ndc restart

* Sat Sep 19 1998 Jeff Johnson <jbj@redhat.com>
- install man pages correctly.
- change K10named to K45named.

* Wed Aug 12 1998 Jeff Johnson <jbj@redhat.com>
- don't start if /etc/named.conf doesn't exist.

* Sat Aug  8 1998 Jeff Johnson <jbj@redhat.com>
- autmagically create /etc/named.conf from /etc/named.boot in %post
- remove echo in %post

* Wed Jun 10 1998 Jeff Johnson <jbj@redhat.com>
- merge in 5.1 mods

* Sun Apr 12 1998 Manuel J. Galan <manolow@step.es>
- Several essential modifications to build and install correctly.
- Modified 'ndc' to avoid deprecated use of '-'

* Mon Dec 22 1997 Scott Lampert <fortunato@heavymetal.org>
- Used buildroot
- patched bin/named/ns_udp.c to use <libelf/nlist.h> for include
  on Redhat 5.0 instead of <nlist.h>

